@@ -7,12 +7,12 @@
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -22,21 +22,31 @@
 #define GAME_H
 
 #define SCORE_PLAYER 0
-#define SCORE_BLACK  1
-#define SCORE_BABY   2
-#define SCORE_BIRD   3
+#define SCORE_BLACK 1
+#define SCORE_BABY 2
+#define SCORE_BIRD 3
 #define SCORE_CACTUS 4
-#define SCORE_FLAG   5
-#define SCORE_MAX    6
+#define SCORE_FLAG 5
+#define SCORE_MAX 6
+
+#include <set>
+#include "general.h"
+#include "glHelp.h"
+
+class Map;
+class Player;
+class Weather;
+class EditMode;
 
 class Game {
  public:
-  Game(char *,class Gamer *gamer);
+  Game(char *, class Gamer *gamer);
+  explicit Game(Map *editmap);
   virtual ~Game();
 
   void tick(Real);
-  void draw();                                   /* Used for normal drawing mode */
-  void drawReflection(Coord3d focus);            /* Used when drawing environmentmaps */
+  void draw();                        /* Used for normal drawing mode */
+  void drawReflection(Coord3d focus); /* Used when drawing environmentmaps */
   void doExpensiveComputations();
   void add(class Animated *);
   void add(class GameHook *);
@@ -46,32 +56,35 @@ class Game {
   void clearLevel();
 
   GLfloat fogColor[4];
-  int localPlayers,isNight,startTime,currentLevelSet,useGrid;
-  double fogThickness,wantedFogThickness;
-  double jumpFactor,oxygenFactor;
+  int localPlayers, isNight, startTime, currentLevelSet, useGrid;
+  double fogThickness, wantedFogThickness;
+  double jumpFactor, oxygenFactor;
+  int edit_mode;
 
-  class Player *player1;
-  class Map *map;
+  Player *player1;
+  Map *map;
   Real gameTime;
-  class Gamer *gamer;
-  class Weather *weather;
+  Gamer *gamer;
+  Weather *weather;
 
   static Game *current;
 
   char levelName[256];
-  char nextLevel[256]; 
+  char nextLevel[256];
   char returnLevel[256]; /* When returning from bonus levels */
 
   /** Records current default settings for score/time when killing
       units and triggering other events */
-  static double defaultScores[SCORE_MAX][2];  
+  static double defaultScores[SCORE_MAX][2];
 
  protected:
+  friend class EditMode;
+  std::set<GameHook *> *hooks;
+
  private:
   void setDefaults();
 
-  class std::set<class Animated *> *objects;
-  class std::set<class GameHook *> *hooks;
+  std::set<Animated *> *objects;
 };
 
 #endif
