@@ -2,18 +2,18 @@
    Displayes the help file
 
    Copyright (C) 2000  Mathias Broxvall
-   		       Yannick Perret
+                       Yannick Perret
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -22,6 +22,9 @@
 #ifndef HELPMODE_H
 #define HELPMODE_H
 
+#include "gameMode.h"
+#include "glHelp.h"
+
 class HelpMode : public GameMode {
  public:
   HelpMode();
@@ -30,20 +33,19 @@ class HelpMode : public GameMode {
   void deactivated();
   void key(int);
   void idle(Real);
-  void mouseDown(int button,int x,int y);
+  void mouseDown(int button, int x, int y);
 
   static void init();
   static HelpMode *helpMode;
+
  private:
   double timeLeft;
-  int isExiting,page;
+  int isExiting, page;
   static SDL_Surface *background;
-  static SDL_Surface *page0,*page1;
+  static SDL_Surface *page0, *page1;
 
-  GLuint bgTexture,p0Texture,p1Texture;
-  GLfloat texMinX, texMinY, texMaxX, texMaxY;
-  GLfloat p0MinX, p0MinY, p0MaxX, p0MaxY;
-  GLfloat p1MinX, p1MinY, p1MaxX, p1MaxY;
+  GLuint bgTexture, p0Texture, p1Texture;
+  GLfloat bgCoord[4], p0coord[4], p1coord[4];
 };
 
 #endif
